AccessTokenVerifyResult class

Properties

channelId → String
The channel ID bound to the access token.
no setter
data → Map<String, dynamic>
Raw data of the response in a Map representation.
no setter
expiresIn → num
Number of seconds until the access token expires. Counting from when the server received the request.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopes → List<String>
The valid scopes bound to this access token.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited