BotFriendshipStatus class

Properties

data → Map<String, dynamic>
Raw data of the response in a Map representation.
no setter
hashCode → int
The hash code for this object.
no setterinherited
isFriend → bool
Indicates the friendship status.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited